@@ -25,8 +25,12 @@ use POEIKC::Daemon::Utility;
 our @inc = @INC;
 our %inc = %INC;
 our $DEBUG;
+our %opt;
+our %connected;
+
+__PACKAGE__->mk_accessors(qw/pidu argv alias ikc_self_port ikc_self_name server_port server_name/);
+
 
-__PACKAGE__->mk_accessors(qw/pidu argv alias ikc_self_port/);
 
 ####
 
@@ -39,12 +43,18 @@ sub ikc_server_param {
 sub init {
 	my $class = shift || __PACKAGE__ ;
 	my $self = $class->new;
-	my %opt = @_;
+	%opt = @_;
 	$DEBUG = $opt{debug};
 	$self->argv($opt{argv}) if $opt{argv};
 	$self->alias($opt{alias} || 'POEIKCd');
 
-	$self->ikc_self_port($opt{port} || $ARGV[0] || 47225);
+	$opt{name} ||= join('_'=>__PACKAGE__ =~ m/(\w+)/g);
+	$self->server_name($opt{name});
+
+	$opt{port} ||= $ARGV[0] || 47225 ;
+	$self->server_port($opt{port});
+
+	$self->ikc_server_param(name		=>$opt{name});
 	$self->ikc_server_param(port		=>$opt{port});
 	$self->ikc_server_param(verbose		=>$opt{Verbose});
 	$self->ikc_server_param(processes	=>$opt{Processes});
@@ -58,10 +68,10 @@ sub init {
 	#$self->pidu->stay(module=>'POEIKC::Daemon::Utility');
 
 	push @{$opt{Module}}, __PACKAGE__, 'POEIKC::Daemon::Utility';
-	$self->pidu->inc->{load}->{ $_ } = [$INC{Class::Inspector->filename($_)},time] for @{$opt{Module}};
+	$self->pidu->inc->{load}->{ $_ } = [$INC{Class::Inspector->filename($_)},scalar localtime] for @{$opt{Module}};
 
 	$0 = sprintf "poeikcd --alias=%s --port=%s",
-				$self->alias, $self->ikc_self_port ;#if $0 =~ /poeikcd/;
+				$self->alias, $self->server_port ;#if $0 =~ /poeikcd/;
 	if ($DEBUG) {
 		no warnings 'redefine';
 		*POE::Component::IKC::Responder::DEBUG = sub { 1 };
@@ -89,11 +99,8 @@ sub poe_run {
 sub spawn
 {
 	my $self = shift;
-	my $name = join('_'=>__PACKAGE__ =~ m/(\w+)/g);
 	my %param = (
-		#port => $self->ikc_self_port ,
-		name => $name,
-		aliases  => [ $name .'_'. Sys::Hostname::hostname],
+		aliases  => [ $self->server_name .'_'. Sys::Hostname::hostname],
 		$self->ikc_server_param
 	);
 
@@ -118,7 +125,7 @@ sub _start {
 	my $object = $poe->object;
 
 	printf "%s PID:%s ... Started!! (%s)\n", $0, $$, scalar(localtime);
-	
+
 	my $kernel = $poe->kernel;
 
 	$object->{start_time} = localtime;
@@ -134,7 +141,7 @@ sub _start {
 		IKC =>
 			#publish => $object->alias, Class::Inspector->methods(__PACKAGE__),
 			publish => $object->alias, [qw/
-				_stop 
+				_stop
 				event_respond
 				execute_respond
 				function_respond
@@ -145,26 +152,80 @@ sub _start {
 
 	if ($DEBUG) {
 		$kernel->post(IKC=>'monitor', '*'=>{
-			register=>'callback_register',
-			unregister =>'callback_unregister',
+			register	=>'debug_monitor_callback_register',
+			unregister	=>'debug_monitor_callback_unregister',
+			subscribe	=>'debug_monitor_callback_subscribe',
+			unsubscribe	=>'debug_monitor_callback_unsubscribe',
+			shutdown	=>'debug_monitor_callback_shutdown',
+			data		=>'(foo)',
+		});
+	}else{
+		$kernel->post(IKC=>'monitor', '*'=>{
+			register	=>'monitor_register',
+			unregister	=>'monitor_unregister',
 		});
 	}
 }
 
-sub callback_register
-{ 
+
+sub monitor_register
+{
 	my $poe = sweet_args ;
-	my (undef, $client, undef, $data ) = @{$poe->args};
-	POEIKC::Daemon::Utility::_DEBUG_log(register=>$client);
+	my $object = $poe->object;
+	my $client = (@{$poe->args})[1];
+	$connected{$client}++;
 }
 
-sub callback_unregister
-{ 
+sub monitor_unregister
+{
 	my $poe = sweet_args ;
-	my (undef, $client, undef, $data ) = @{$poe->args};
-	POEIKC::Daemon::Utility::_DEBUG_log(unregister=>$client);
+	my $object = $poe->object;
+	my $client = (@{$poe->args})[1];
+	delete $connected{$client} if $connected{$client};
 }
 
+
+
+
+sub debug_monitor_callback_register
+{
+	my $poe = sweet_args ;
+	my $object = $poe->object;
+	my $client = (@{$poe->args})[1];
+	$connected{$client}++;
+	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
+}
+
+sub debug_monitor_callback_unregister
+{
+	my $poe = sweet_args ;
+	my $object = $poe->object;
+	my $client = (@{$poe->args})[1];
+	delete $connected{$client} if $connected{$client};
+	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
+}
+
+sub debug_monitor_callback_subscribe
+{
+	my $poe = sweet_args ;
+	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
+}
+
+sub debug_monitor_callback_unsubscribe
+{
+	my $poe = sweet_args ;
+	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
+}
+
+sub debug_monitor_callback_shutdown
+{
+	my $poe = sweet_args ;
+	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
+}
+
+
+
+
 sub sig_stop {
 	my $poe = sweet_args;
 	my $kernel = $poe->kernel;
@@ -187,7 +248,7 @@ sub shutdown {
 	$kernel->call( IKC => 'shutdown');
 	$kernel->stop();
 	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log();
-	killall('KILL', $0); # SIGKILL 
+	killall('KILL', $0); # SIGKILL
 	printf "%s PID:%s ... stopped!! (%s)\n", $0, $$, scalar(localtime);
 }
 
@@ -211,12 +272,12 @@ sub something_respond {
 	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($request);
 
 	my @something = $object->pidu->_distinguish( poe=>$poe, args => $args );
-	@something ? 
+	@something ?
 		$kernel->call($session, execute_respond => @something, $rsvp):
 
 	$kernel->post( IKC => post => $rsvp, {poeikcd_error=>
 		'It is not discriminable. '.
-		q{"ModuleName::functionName" or  "ClassName->methodName" or "AliasName eventName"} 
+		q{"ModuleName::functionName" or  "ClassName->methodName" or "AliasName eventName"}
 	});
 }
 
@@ -251,7 +312,7 @@ sub execute_respond {
 	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($from, $args, $rsvp);
 
 	ref $args ne 'ARRAY' and
-		return $kernel->call( IKC => post => $rsvp, 
+		return $kernel->call( IKC => post => $rsvp,
 		{poeikcd_error=>"A parameter is not an Array reference. It is ".ref $args} );
 
 	my $module = shift @{$args};
@@ -271,7 +332,7 @@ sub execute_respond {
 	if ($module eq 'POEIKC::Daemon::Utility'){
 		#$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($rsvp);
 		my @re = eval {
-			$method ? 
+			$method ?
 			$object->pidu->$method(
 				poe=>$poe, rsvp=>$rsvp, from=>$from, args=>$args
 			) : grep {not /^\_/ and not /^[A-Z]+$/} @{Class::Inspector->methods($module)};
@@ -320,12 +381,12 @@ POEIKC::Daemon - POE IKC daemon
 
 L<poeikcd>
 
-	poeikcd start -p=47225 
-	poeikcd stop  -p=47225 
+	poeikcd start -p=47225
+	poeikcd stop  -p=47225
 	poeikcd --help
 
-And then 
-L<poikc> (POK IKC Client) 
+And then
+L<poikc> (POK IKC Client)
 
 	poikc -H hostname [options] args...
 	poikc --help
@@ -337,7 +398,7 @@ POEIKC::Daemon is daemon of POE::Component::IKC
 
 =head1 AUTHOR
 
-Yuji Suzuki E<lt>yuji.suzuki.perl@gmail.comE<gt>
+Yuji Suzuki E<lt>yujisuzuki@mail.arbolbell.jpE<gt>
 
 =head1 LICENSE
 
