@@ -542,7 +542,7 @@ sub _distinguish {
 
 sub _DEBUG_log {
 	$DEBUG or return;
-	Date::Calc->use or return;
+	Date::Calc->use or return(warn($@));
 	#YAML->use or return;
 	my ($pack, $file, $line, $subroutine) = caller(0);
 	my $levels_up = 0 ;
@@ -607,7 +607,7 @@ POEIKC::Daemon::Utility is Utility for POEIKC::Daemon
 
 =head1 AUTHOR
 
-Yuji Suzuki E<lt>yuji.suzuki.perl@gmail.comE<gt>
+Yuji Suzuki E<lt>yujisuzuki@mail.arbolbell.jpE<gt>
 
 =head1 LICENSE
 
